@@ -114,7 +114,7 @@ setClass("config_Shadow",
     ),
     content_balancing = list(method = "STA"),
     MIP = list(
-      solver = "LPSOLVE",
+      solver = "LPSYMPHONY",
       verbosity = -2,
       time_limit = 60,
       gap_limit = .05,
@@ -180,51 +180,69 @@ setClass("config_Shadow",
   ),
   validity = function(object) {
     errors <- NULL
-    if (!toupper(object@MIP$solver) %in% c("LPSYMPHONY", "RSYMPHONY", "LPSOLVE", "GUROBI", "RGLPK")) {
-      errors <- c(errors, "@MIP$solver must be one of lpsymphony, Rsymphony, lpSolve, gurobi, or Rglpk.")
-    }
-    if (toupper(object@MIP$solver) == "GUROBI") {
-      if (!requireNamespace("gurobi", quietly = TRUE)) {
-        errors <- c(errors, "GUROBI was specified but is not installed.")
-      }
-    }
-    if (toupper(object@MIP$solver) == "RSYMPHONY") {
-      if (!requireNamespace("Rsymphony", quietly = TRUE)) {
-        errors <- c(errors, "RSYMPHONY was specified but is not installed.")
-      }
-    }
-    if (!object@item_selection$method %in% c("MFI", "MPWI", "EB", "FB")) {
-      errors <- c(errors, "@item_selection$method must be one of MFI, MPWI, EB, or FB")
+    if (toupper(object@MIP$solver) %not in% c("LPSYMPHONY", "RSYMPHONY", "LPSOLVE", "GUROBI", "RGLPK")) {
+      msg <- sprintf("Unrecognized option in @MIP$solver                : %s", object@MIP$solver)
+      errors <- c(errors, msg)
     }
 
-    if (!object@content_balancing$method %in% c("NONE", "STA")) {
-      errors <- c(errors, "@content_balancing$method must be one of NONE or STA")
+    for (solver_name in c("gurobi", "Rsymphony", "lpsymphony", "Rglpk")) {
+      if (toupper(object@MIP$solver) == toupper(solver_name)) {
+        if (!requireNamespace(solver_name, quietly = TRUE)) {
+          msg <- sprintf("could not find the specified solver package                  : %s", solver_name)
+          errors <- c(errors, msg)
+        }
+      }
     }
-    if (!object@refresh_policy$method %in%
+
+    if (toupper(object@item_selection$method) %not in% c("MFI", "MPWI", "EB", "FB")) {
+      msg <- sprintf("Unrecognized option in @item_selection$method     : %s", object@item_selection$method)
+      errors <- c(errors, msg)
+    }
+
+    if (object@content_balancing$method %not in% c("NONE", "STA")) {
+      msg <- sprintf("Unrecognized option in @content_balancing$method : %s", object@content_balancing$method)
+      errors <- c(errors, msg)
+    }
+    if (object@refresh_policy$method %not in%
       c("ALWAYS", "POSITION", "INTERVAL", "THRESHOLD", "INTERVAL-THRESHOLD", "STIMULUS", "SET", "PASSAGE")) {
-      errors <- c(errors, "@refresh_policy$method is not valid.")
+      msg <- sprintf("Unrecognized option in @refresh_policy$method : %s", object@refresh_policy$method)
+      errors <- c(errors, msg)
     }
-    if (!object@exposure_control$method %in% c("NONE", "ELIGIBILITY", "BIGM", "BIGM-BAYESIAN")) {
-      errors <- c(errors, "@exposure_control$method is not valid.")
+    if (object@exposure_control$method %not in% c("NONE", "ELIGIBILITY", "BIGM", "BIGM-BAYESIAN")) {
+      msg <- sprintf("Unrecognized option in @exposure_control$method : %s", object@exposure_control$method)
+      errors <- c(errors, msg)
     }
     if (object@exposure_control$n_segment != length(object@exposure_control$segment_cut) - 1) {
-      errors <- c(errors, "@exposure_control$n_segment must match @exposure_control$segment_cut.")
+      msg <- "@exposure_control$n_segment must match @exposure_control$segment_cut."
+      errors <- c(errors, msg)
     }
-    if (!object@stopping_criterion$method %in% c("FIXED")) {
-      errors <- c(errors, "@stopping_criterion$method must be FIXED.")
+    if (object@stopping_criterion$method %not in% c("FIXED")) {
+      msg <- sprintf("Unrecognized option in @stopping_criterion$method : %s", object@stopping_criterion$method)
+      errors <- c(errors, msg)
     }
-    if (!object@interim_theta$method %in% c("EAP", "MLE", "EB", "FB")) {
-      errors <- c(errors, "@interim_theta$method must be one of EAP, MLE, EB, or FB.")
+    if (object@interim_theta$method %not in% c("EAP", "MLE", "EB", "FB")) {
+      msg <- sprintf("Unrecognized option in @interim_theta$method : %s (must be one of EAP, MLE, EB, or FB)", object@interim_theta$method)
+      errors <- c(errors, msg)
     }
-    if (!object@final_theta$method %in% c("EAP", "MLE", "EB", "FB")) {
-      errors <- c(errors, "@final_theta$method must be one of EAP, MLE, EB, or FB.")
+    if (object@final_theta$method %not in% c("EAP", "MLE", "EB", "FB")) {
+      msg <- sprintf("Unrecognized option in @final_theta$method : %s (must be one of EAP, MLE, EB, or FB)", object@final_theta$method)
+      errors <- c(errors, msg)
     }
-    if (object@exposure_control$method %in% c("BIGM-BAYESIAN") && !object@interim_theta$method %in% c("EB", "FB")) {
-      errors <- c(errors, "'BIGM-BAYESIAN' exposure_control$method requires interim_theta$method of EB or FB.")
+    if (toupper(object@final_theta$method) == "EAP") {
+      if (toupper(object@final_theta$prior_dist) %not in% c("NORMAL", "UNIFORM")) {
+        msg <- sprintf("Unrecognized option in @final_theta$prior_dist : %s (must be one of NORMAL or UNIFORM when @final_theta$method is EAP)", object@final_theta$prior_dist)
+        errors <- c(errors, msg)
+      }
+    }
+
+    if ((object@exposure_control$method == c("BIGM-BAYESIAN")) &&
+      (object@interim_theta$method %not in% c("EB", "FB"))) {
+      errors <- c(errors, "exposure_control$method == 'BIGM-BAYESIAN' requires interim_theta$method to be EB or FB.")
     }
     if (length(errors) == 0) {
       return(TRUE)
     } else {
+      errors = paste0(c("", errors), collapse = '\n')
       return(errors)
     }
   }
