@@ -11,36 +11,7 @@ css_y <- "overflow-y:scroll; max-height: 65vh"
 ui <- fluidPage(
   theme = shinytheme("lumen"),
   shinyjs::useShinyjs(),
-  tags$head(
-    tags$style(type = "text/css", ":focus { outline: -webkit-focus-ring-color auto 0px; }"),
-    tags$style(type = "text/css", "h2 { font-size: 170%; }"),
-    tags$style(type = "text/css", "h3 { font-size: 12px; font-weight: bold; text-transform: uppercase; color: #555555; }"),
-    tags$style(type = "text/css", ".form-control { font-size: 12px; text-transform: uppercase; color: #555555; }"),
-    tags$style(type = "text/css", "i { display: inline-block; margin-right: 0.2em; }"),
-    tags$style(type = "text/css", "label, .form-group, .progress { margin-bottom: 0px; }"),
-    tags$style(type = "text/css", "select { min-width: 100%; max-width: 100%; }"),
-    tags$style(type = "text/css", ".span4 { min-width: 100%; max-width: 100%; }"),
-    tags$style(type = "text/css", ".well { min-width: 100%; max-width: 100%; }"),
-    tags$style(type = "text/css", "#text_output { background-color: rgba(64,64,64,1); color: cyan; overflow-y:auto; height: 64px; display: flex; flex-direction: column-reverse; }"),
-    tags$style(type = "text/css", ".shiny-notification { font-size: 20px; background-color: #404040; color: #fff; }"),
-    tags$style(type = "text/css", "#shiny-notification-panel { width: 500px; }"),
-    tags$style(type = "text/css", ".progress { margin-top: -10px; margin-bottom: 15px; }"),
-    tags$style(type = "text/css", ".progress.shiny-file-input-progress { margin-top: 0px; margin-bottom: 0px; }"),
-    tags$style(type = "text/css", ".progress-number { font-size: 0px; }"),
-    tags$style(type = "text/css", ".progress-bar { line-height: 1.5em; -webkit-box-shadow: inset 0 0px 0 rgba(0,0,0,0.15); box-shadow: inset 0 0px 0 rgba(0,0,0,0.15);}"),
-    tags$style(type = "text/css", ".btn { width: 100%; border-width: 1px; padding: 7px 12px; }"),
-    tags$style(type = "text/css", ".btn:hover { border-width: 1px; margin-top: 0px; }"),
-    tags$style(type = "text/css", ".well { -webkit-box-shadow: inset 0 0px 0 rgba(0,0,0,0.05); box-shadow: inset 0 0px 0 rgba(0,0,0,0.05); }"),
-    tags$style(type = "text/css", ".form-control { -webkit-box-shadow: inset 0 0px 0 rgba(0,0,0,0.075); box-shadow: inset 0 0px 0 rgba(0,0,0,0.075); }"),
-    tags$style(type = "text/css", ".form-control[readonly] { background-color: transparent; height: auto; }"),
-    tags$style(type = "text/css", ".form-control[disabled] { background-color: #ffffff; opacity: 0.2; }"),
-    tags$style(type = "text/css", ".progress { -webkit-box-shadow: inset 0 2px 0 rgba(0,0,0,0.1); box-shadow: inset 0 0px 0 rgba(0,0,0,0.1); }"),
-    tags$style(type = "text/css", "button { overflow: hidden; }"),
-    tags$style(type = "text/css", ".btn.disabled { opacity: 0.2; }"),
-    tags$style(type = "text/css", "html { overflow:scroll; overflow-x:hidden; }"),
-    tags$style(type = "text/css", "::-webkit-scrollbar { width:0; background:transparent; }"),
-    tags$style(type = "text/css", "label { font-weight: bold; text-transform: uppercase; font-size: 12px; }")
-  ),
+  includeCSS("styles.css"),
 
   titlePanel("TestDesign: Optimal Test Assembly"),
 
